Changeset: a9b7192ac932 for MonetDB
URL: http://dev.monetdb.org/hg/MonetDB?cmd=changeset;node=a9b7192ac932
Modified Files:
        java/src/main/java/nl/cwi/monetdb/jdbc/MonetDatabaseMetaData.java
Branch: default
Log Message:

Change name of internal private method.
Instead of getting Env properties we want to get the values of the Env 
properties, so improved the method name.


diffs (63 lines):

diff --git a/java/src/main/java/nl/cwi/monetdb/jdbc/MonetDatabaseMetaData.java 
b/java/src/main/java/nl/cwi/monetdb/jdbc/MonetDatabaseMetaData.java
--- a/java/src/main/java/nl/cwi/monetdb/jdbc/MonetDatabaseMetaData.java
+++ b/java/src/main/java/nl/cwi/monetdb/jdbc/MonetDatabaseMetaData.java
@@ -46,12 +46,12 @@ public class MonetDatabaseMetaData exten
        }
 
        /**
         * Internal cache for 3 environment properties retrieved from the
         * server, to avoid querying the server over and over again.
         * Once a value is read, it is kept in the private env_* variables for 
reuse.
         * We currently only need the env values of: current_user, 
monet_version and max_clients.
         */
-       private synchronized void getEnvProperties() {
+       private synchronized void getEnvValues() {
                Statement st = null;
                ResultSet rs = null;
                try {
@@ -134,7 +134,7 @@ public class MonetDatabaseMetaData exten
        @Override
        public String getUserName() throws SQLException {
                if (env_current_user == null)
-                       getEnvProperties();
+                       getEnvValues();
                return env_current_user;
        }
 
@@ -209,7 +209,7 @@ public class MonetDatabaseMetaData exten
        @Override
        public String getDatabaseProductVersion() throws SQLException {
                if (env_monet_version == null)
-                       getEnvProperties();
+                       getEnvValues();
                return env_monet_version;
        }
 
@@ -1296,7 +1296,7 @@ public class MonetDatabaseMetaData exten
        @Override
        public int getMaxConnections() {
                if (env_max_clients == null)
-                       getEnvProperties();
+                       getEnvValues();
 
                int max_clients = 16;
                if (env_max_clients != null) {
@@ -3265,7 +3265,7 @@ public class MonetDatabaseMetaData exten
        @Override
        public int getDatabaseMajorVersion() throws SQLException {
                if (env_monet_version == null)
-                       getEnvProperties();
+                       getEnvValues();
                int major = 0;
                if (env_monet_version != null) {
                        try {
@@ -3287,7 +3287,7 @@ public class MonetDatabaseMetaData exten
        @Override
        public int getDatabaseMinorVersion() throws SQLException {
                if (env_monet_version == null)
-                       getEnvProperties();
+                       getEnvValues();
                int minor = 0;
                if (env_monet_version != null) {
                        try {
@@ -46,12 +46,12 @@ public class MonetDatabaseMetaData exten
 
        /**
-        * Internal cache for 3 environment properties retrieved from the
+        * Internal cache for 3 environment values retrieved from the
         * server, to avoid querying the server over and over again.
         * Once a value is read, it is kept in the private env_* variables for 
_______________________________________________
checkin-list mailing list
checkin-list@monetdb.org
https://www.monetdb.org/mailman/listinfo/checkin-list

Reply via email to